#
# spec file for package live-net-installer
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_url http://download.opensuse.org

# AArch64 has a different repo url on TW and Leap < 15.3
%if !0%{?sle_version} || 0%{?sle_version} < 150300
%ifarch aarch64
%define base_url http://download.opensuse.org/ports/aarch64
%endif
%endif

Name:           live-net-installer
Version:        1.0
Release:        lp154.1.2
Summary:        Makes the installation available from a running system
License:        BSD-3-Clause
Group:          System/YaST
URL:            https://build.opensuse.org/package/show/openSUSE:Factory:Live/live-net-installer
Source1:        start-install.sh
Source2:        installation.desktop
Source3:        COPYING
Source4:        extend
Source5:        upgrade.desktop
BuildRequires:  coreutils
BuildRequires:  yast2-installation
Requires:       util-linux
Requires:       xdg-utils
Requires:       yast2-installation
# yast2-installation should require this, but it doesn't
Requires:       bcache-tools
Requires:       btrfsprogs
Requires:       cryptsetup
Requires:       device-mapper
Requires:       dmraid
Requires:       e2fsprogs
Requires:       exfatprogs
Requires:       fcoe-utils
Requires:       mdadm
Requires:       multipath-tools
Requires:       ntfs-3g
Requires:       ntfsprogs
Requires:       nvme-cli
Requires:       open-iscsi
Requires:       quota
Requires:       snapper
Requires:       xfsprogs

%description
This package contains files that allow starting the installer from a
running (live) system.

%prep
%setup -q -T -c
cp %{SOURCE3} .

URL=
%if 0%{?is_opensuse}
# Tumbleweed?
%if 0%{?suse_version} >= 1550 && !0%{?sle_version}
URL="%{base_url}/tumbleweed/repo/oss"
%endif

# Leap?
%if 0%{?sle_version}
leap="$(expr %{?sle_version} / 100)"
leap_min="$(expr ${leap} % 100)" || true # leap_min can be 0, which causes expr to exit(1)
leap_maj="$(expr ${leap} / 100)"
URL="%{base_url}/distribution/leap/${leap_maj}.${leap_min}/repo/oss"
%endif
%endif

if [ -z "$URL" ]; then
	echo "Building for unknown distro - no repository specified."
    exit 1
fi
sed -i"" "s=@URL@=${URL}=" %{SOURCE1}

%build

%install
install -Dm 755 %{SOURCE1} %{buildroot}%{_sbindir}/start-install.sh
install -Dm 644 %{SOURCE2} %{buildroot}%{_datadir}/applications/installation.desktop
install -Dm 644 %{SOURCE5} %{buildroot}%{_datadir}/applications/upgrade.desktop
install -Dm 755 %{SOURCE4} %{buildroot}/bin/extend

%files
%license COPYING
/bin/extend
%{_sbindir}/start-install.sh
%{_datadir}/applications/installation.desktop
%{_datadir}/applications/upgrade.desktop

%changelog
* Tue Apr  6 2021 Fabian Vogt <fvogt@suse.com>
- Switch from exfat-utils to exfatprogs, see also gh#yast/yast-storage-ng#1214
* Wed Mar 31 2021 Fabian Vogt <fvogt@suse.com>
- Fixup /var/cache/zypp after the installation
- Comments aren't allowed in install.inf, move it outside
- Run YaST in a mount namespace
* Mon Mar  8 2021 Fabian Vogt <fvogt@suse.com>
- Add some more runtime dependencies which yast2-storage is missing
* Wed Feb  3 2021 Fabian Vogt <fvogt@suse.com>
- Stop packagekitd before starting the installation (boo#1181606)
* Mon Feb  1 2021 Fabian Vogt <fvogt@suse.com>
- Fix typo breaking the URL on Leap 15.3 on aarch64
* Wed Jan  6 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix EFI detection for non-x86 with kernel 5.10+ - boo#1180408
* Fri Dec 11 2020 Fabian Vogt <fvogt@suse.com>
- Remove special handling for AArch64 on Leap > 15.2
* Fri Mar  6 2020 Fabian Vogt <fvogt@suse.com>
- Add some more Requires for the installation (boo#1138045)
* Thu Dec  5 2019 Fabian Vogt <fvogt@suse.com>
- Stop nscd before starting the installation (boo#1155687)
* Mon Jul 29 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix URL for aarch64
- URL is arch specific, so drop noarch
* Wed Jan 16 2019 Fabian Vogt <fvogt@suse.com>
- Move extend to /bin/extend (boo#1122181)
* Fri Nov 30 2018 lslezak@suse.cz
- Move icons to the package, do not depend on the YaST branding
  (boo#1109310)
* Tue Jun 19 2018 ancor@suse.com
- Option to perform a system upgrade instead of a fresh install
* Mon May 28 2018 fvogt@suse.com
- Add /sbin:/usr/sbin to $PATH to workaround boo#1094842
* Thu May  3 2018 fvogt@suse.com
- Move start-install.sh to /usr/sbin
- Add extend script to fake extension rpm loading (boo#1013206)
* Thu Jan 11 2018 fvogt@suse.com
- Support Leap 15.0 by detecting the OS and setting the RepoUrl
  appropriately
* Thu Sep 28 2017 fvogt@suse.com
- Change cmdline entry generation in start-install.sh:
  * No useless use of cat ~(=^‥^)
  * Strip parameters that the dracut-based boot injects to prevent
    them from getting added to the installed system (boo#1059298)
* Tue Aug  8 2017 fvogt@suse.com
- Initial package, separated from kiwi-config-openSUSE
